@@ -7,9 +7,9 @@ from ..device_base import DeviceBase
 
 class Attenuator(DeviceBase):
     @abstractmethod
-    def set_level(self, level_dB: int, ch: int):
+    def set_loss(self, dB: int, id: str):
         ...
 
     @abstractmethod
-    def get_level(self, ch: int) -> u.Quantity:
+    def get_loss(self, id: str) -> u.Quantity:
         ...
