@@ -1,7 +1,7 @@
 __all__ = ["CPZ7415V"]
 
 import time
-from typing import Dict, Literal
+from typing import Dict, Literal, Union
 
 import astropy.units as u
 
@@ -71,18 +71,19 @@ class CPZ7415V(Motor):
 
     Identifier = "rsw_id"
 
-    def __init__(self) -> None:
+    def __init__(self, **kwargs) -> None:
         self.logger = get_logger(self.__class__.__name__)
 
         self.rsw_id = self.Config.rsw_id
         self.use_axes = self.Config.useaxes.lower()
-        self.axis_mapping = dict(self.Config.axis.items())
         self.speed_to_pulse_factor = utils.AliasedDict(
             self.Config.speed_to_pulse_factor.items()
         )
         _config = {ax: getattr(self.Config, ax) for ax in self.use_axes}
 
-        self.speed_to_pulse_factor.alias(**{v: k for k, v in self.axis_mapping.items()})
+        self.speed_to_pulse_factor.alias(
+            **{v: k for k, v in self.Config.channel.items()}
+        )
 
         self.motion = {
             ax: dict(getattr(self.Config, f"{ax}_motion").items())
@@ -90,8 +91,8 @@ class CPZ7415V(Motor):
         }
         self.motion_mode = {ax: conf.mode for ax, conf in _config.items()}
         self.pulse_conf = {ax: conf.pulse_conf for ax, conf in _config.items()}
-        self.default_speed = {ax: conf.motion_speed for ax, conf in _config.items()}
-        self.low_speed = {ax: conf.motion_low_speed for ax, conf in _config.items()}
+        self.default_speed = {ax: conf.motion["speed"] for ax, conf in _config.items()}
+        self.low_speed = {ax: conf.motion["low_speed"] for ax, conf in _config.items()}
 
         self.last_direction = {ax: 0 for ax in self.use_axes}
 
@@ -126,9 +127,9 @@ class CPZ7415V(Motor):
         return {ax: st for ax, st in zip(self.use_axes, status)}
 
     def _parse_ax(self, axis: str) -> Literal["x", "y", "z", "u"]:
-        if axis in self.use_axes:
-            return axis
-        return self.axis_mapping[axis.lower()]
+        if axis.lower() in self.use_axes:
+            return axis.lower()
+        return self.Config.channel[axis.lower()]
 
     def get_speed(self, axis: str) -> u.Quantity:
         ax = self._parse_ax(axis)
@@ -159,13 +160,16 @@ class CPZ7415V(Motor):
                 self._start(abs(speed), step, ax)
                 time.sleep(1e-2)
 
-    def set_step(self, step: int, axis: str) -> None:
+    def set_step(self, step: Union[str, int], axis: str) -> None:
         ax = self._parse_ax(axis)
         if self.motion_mode[ax] != "ptp":
             raise RuntimeError(
                 "Position setting is only supported in point-to-point (ptp) mode, "
                 f"but {axis=!r} is controlled in {self.motion_mode[ax]!r} mode."
             )
+        if isinstance(step, str):
+            step = self.Config.position[step.lower()]
+
         if self.current_motion[ax] != 0:
             self._change_step(step, ax)
         else:
@@ -201,6 +205,8 @@ class CPZ7415V(Motor):
                 time.sleep(1e-4)
 
     def finalize(self) -> None:
-        self.io.output_do([0, 0, 0, 0])
-        for ax in self.use_axes:
-            self._stop(ax)
+        try:
+            for ax in self.use_axes:
+                self._stop(ax)
+        finally:
+            self.io.output_do([0, 0, 0, 0])
