@@ -25,7 +25,7 @@ class FSW0020(SignalGenerator):
     def set_freq(self, GHz: Union[int, float]) -> None:
         with busy(self, "busy"):
             self.sg.freq_set(GHz)
-            time.sleep(1)
+            time.sleep(0.1)
 
     def set_power(self, dBm: Union[int, float]) -> None:
         """Set the power of the signal generator output.
@@ -39,12 +39,12 @@ class FSW0020(SignalGenerator):
         """
         with busy(self, "busy"):
             self.sg.power_set(dBm)
-            time.sleep(1)
+            time.sleep(0.1)
 
     def get_freq(self) -> u.Quantity:
         with busy(self, "busy"):
             f = self.sg.freq_query()
-            time.sleep(1)
+            time.sleep(0.1)
             return f * u.Hz
 
     def get_power(self) -> u.Quantity:
@@ -58,23 +58,23 @@ class FSW0020(SignalGenerator):
         """
         with busy(self, "busy"):
             f = self.sg.power_query()
-            time.sleep(1)
+            time.sleep(0.1)
             return f * dBm
 
     def start_output(self) -> None:
         with busy(self, "busy"):
             self.sg.output_on()
-            time.sleep(1)
+            time.sleep(0.1)
 
     def stop_output(self) -> None:
         with busy(self, "busy"):
             self.sg.output_off()
-            time.sleep(1)
+            time.sleep(0.1)
 
     def get_output_status(self) -> Optional[bool]:
         with busy(self, "busy"):
             f = self.sg.output_query()
-            time.sleep(1)
+            time.sleep(0.1)
             if f == 1:
                 return True
             elif f == 0:
