@@ -10,14 +10,12 @@ don't explicitly appear in your script.
 
 __all__ = ["scan", "point", "scan_to_point_equivalency"]
 
-from typing import Callable, List, Tuple
+from typing import List
 
 import astropy.units as u
 
+from .typing import EquivalencyType
 
-EquivalencyType = Tuple[
-    u.Unit, u.Unit, Callable[[float], float], Callable[[float], float]
-]
 
 scan = u.def_unit("scan")
 """Custom unit to handle number of scan lines."""
@@ -25,9 +23,13 @@ scan = u.def_unit("scan")
 point = u.def_unit("point")
 """Custom unit to handle number of pointing positions."""
 
-# Enable use of the units in parsing it like ``u.Unit('scan')``, or other astropy
+dBm: u.DecibelUnit = u.dB(u.mW)
+"""Custom unit to handle power in dBm."""
+
+# Enable the use of the units in parsing it like ``u.Unit('scan')``, or other astropy
 # functions e.g. ``scan.find_equivalent_units()``
 u.add_enabled_units([scan, point])
+u.add_enabled_aliases({"dBm": dBm})
 
 
 def scan_to_point_equivalency(points_per_scan: int) -> List[EquivalencyType]:
